### cge 0.7.5
###### A lightweight terminal graphics engine.
***

Looking for a simple, lightweight package? Easily managable features?

cgepy will handle that, with a sturdy system to build interfaces on top of.
***
Current features:
* A flexible grid system where you can swap between multiple canvases.
* Custom coloring that is applicable to all text
* Higher resolution display capabilities vs. colored unicode full blocks.
* A basic sprite system for easier manipulation of the canvas.
* Multiple screen clearing methods for greater control of your programs.
***
Upcoming features:
* The sprite system will be revamped entirely to allow systematic loading and manipulation of many points at once.
* A stroke function to eliminate repeated write operations, save time, and serve as a replacement for the old map system.
* Text will be added back as a more integrated feature that will come built into the existing grid framework.

***
###### Note: cgepy has not been tested on windows, and coloring may not appear due to how powershell handles ansi. This can be fixed via the colorama library. 